@@ -7,6 +7,12 @@
  *
  */
 
+
+/**
+   <p>$BFsJ,LZ$rI=$9(Bsbtree_t$B$H!"0lO"$N4X?t$rDs6!$7$^$9!#(B</p>
+*/
+
+
 #ifndef _SCALL_BTREE_H_
 #define _SCALL_BTREE_H_
 
