@@ -7,6 +7,14 @@
  *
  */
 
+/**
+   <p>$B%R!<%W9=B$$r07$&0Y$N9=B$BN$H4X?t$rDs6!$9$k!#%R!<%W9=B$$H$$$&$N$O(B
+   $B0l8+%9%?%C%/$HF1MM$NA`:n$,Ds6!$5$l$F$$$k$h$&$K8+$($k$,!"(Bpop()$B$7$?$H$-$K(B
+   $B>o$K0lHVBg$-$$%G!<%?$rJV$9$3$H$rJ]>Z$7$F$$$k!#(B</p>
+
+   <p>$B$D$^$j!"(B{1, 2, 3}$B$H$$$&=gHV$G(Bpush()$B$7$?8e$K=g<!(Bpop()$B$9$k$H(B{3, 2, 1}
+   $B$H$$$&=g=x$GJV$5$l$k!#(B</p>
+*/
 
 #ifndef _SCALL_HEAP_H_
 #define _SCALL_HEAP_H_
