@@ -1,19 +1,42 @@
-/**
- * $Id: iterator.h,v 1.1 2004/06/21 16:44:17 jklein Exp $
+/*
+ * $Id: iterator.h,v 1.2 2004/06/26 06:58:13 jklein Exp $
  * $Author: jklein $
  * $Log: iterator.h,v $
+ * Revision 1.2  2004/06/26 06:58:13  jklein
+ * small fix in each header files.
+ *
  * Revision 1.1  2004/06/21 16:44:17  jklein
  * Added iterator.
  *
  */
 
+/**
+ * siterator_tϳƥꥹȹ¤ؤݲ줿ˡ󶡤롣
+ * ƥꥹȹ¤Ϥsiterator_tѰդ뤳ȡ
+ * ʲ
+ * <pre>
+ * siterator_t *itr = s_xxxx_iterator(xxxx);
+ * spointer contents;
+ * 
+ * while ((contents = s_iterator_next(itr))) != NULL) {
+ *		'contents'Ѥ
+ * }
+ *
+ * itr->free(itr);
+ * </pre>
+ * ǽ餫롼פľȤ s_iterator_clear() Ƥ֡
+ * ˤꥤƥ졼˺ƽ롣
+ * ʤsiterator.dataϤ줾Υƥ졼μ
+ * ǻȤǽΤƤΰʤΤǡʤȡ
+ */
 
-#ifndef _SC_ITERATOR_H_
-#define _SC_ITERATOR_H_
+
+#ifndef _SCALE_ITERATOR_H_
+#define _SCALE_ITERATOR_H_
 
 #include "scale/commons.h"
 
-
+/** ƥ졼֥ */
 typedef struct _sc_iterator siterator_t;
 
 typedef spointer (* s_itr_nextf)(siterator_t *);
@@ -21,28 +44,7 @@ typedef void (* s_itr_clearf)(siterator_t *);
 typedef void (* s_itr_freef)(siterator_t *);
 
 
-/**
- * siterator_tϳƥꥹȹ¤ؤݲ줿ˡ
- * 󶡤롣
- * ƥꥹȹ¤Ϥsiterator_t
- * Ѱդ뤳ȡ
- * Ȥ
- * ---------------------------------------------
- * siterator_t *itr = s_xxxx_iterator(xxxx);
- * spointer contents;
- * 
- * while ((contents = itr->next(itr)) != NULL) {
- *		'contents'Ѥ
- * }
- *
- * itr->free(itr);
- * ---------------------------------------------
- * ǽ餫롼פľȤ itr->clear Ƥ֡
- * ˤꥤƥ졼˺ƽ롣
- * ʤsiterator.dataϤ줾Υƥ졼μ
- * ǻȤǽΤƤΰʤΤǡʤȡ
- */
-
+/** ƥ졼¤ */
 struct _sc_iterator {
 	spointer listdata;
 	spointer data;
@@ -52,4 +54,14 @@ struct _sc_iterator {
 };
 
 
-#endif /* _SC_ITERATOR_H_ */
+/** ƥ졼λؤƤǡ֤Υǡ֤򤹤 */
+#define s_iterator_next(__itr) (__itr->next(__itr))
+
+/** ƥ졼ƽ */
+#define s_iterator_clear(__itr) (__itr->clear(__itr))
+
+/** ƥ졼 */
+#define s_iterator_free(__itr) (__itr->free(__itr))
+
+
+#endif /* _SCALE_ITERATOR_H_ */
