@@ -1,15 +1,25 @@
-/**
- * $Id: stack.h,v 1.2 2004/06/21 16:44:17 jklein Exp $
+/*
+ * $Id: stack.h,v 1.4 2004/06/26 06:58:13 jklein Exp $
  * $Author: jklein $
  * $Log: stack.h,v $
+ * Revision 1.4  2004/06/26 06:58:13  jklein
+ * small fix in each header files.
+ *
+ * Revision 1.3  2004/06/24 15:16:50  jklein
+ * sxarray_t was added for abstruction of collection structure.
+ *
  * Revision 1.2  2004/06/21 16:44:17  jklein
  * Added iterator.
- *
  */
 
+/**
+   <p>$B%9%?%C%/9=B$$H0lO"$NA`:n$rDs6!$9$k!#A`:n$NBgH>$O%^%/%m$GDj5A$5$l$F$$$k(B
+   </p>
+*/
 
-#ifndef _SC_STACK_H_
-#define _SC_STACK_H_
+
+#ifndef _SCALE_STACK_H_
+#define _SCALE_STACK_H_
 
 #include "scale/commons.h"
 #include "scale/vector.h"
@@ -28,4 +38,4 @@ spointer		s_stack_peek(sstack_t *);
 spointer		s_stack_pop(sstack_t *);
 
 
-#endif /* _SC_STACK_H_ */
+#endif /* _SCALE_STACK_H_ */
