@@ -1,7 +1,13 @@
-/**
- * $Id: vector.h,v 1.2 2004/06/21 16:44:17 jklein Exp $
+/*
+ * $Id: vector.h,v 1.4 2004/06/26 06:58:13 jklein Exp $
  * $Author: jklein $
  * $Log: vector.h,v $
+ * Revision 1.4  2004/06/26 06:58:13  jklein
+ * small fix in each header files.
+ *
+ * Revision 1.3  2004/06/24 15:16:50  jklein
+ * sxarray_t was added for abstruction of collection structure.
+ *
  * Revision 1.2  2004/06/21 16:44:17  jklein
  * Added iterator.
  *
@@ -10,11 +16,21 @@
  *
  * Revision 1.1.1.1  2004/06/21 09:29:33  jklein
  * import scale
- *
  */
 
-#ifndef _SC_VECTOR_H_
-#define _SC_VECTOR_H_
+/**
+   <p>$B%Y%/%H%k9=B$$rDs6!$7$^$9!#$3$l$ODL>o$NG[Ns$rMQ$$$F<BAu$5$l$F$$$k$N$G!"(B
+   $B%i%s%@%`%"%/%;%9$KBP$7$F$O>o$K(BO(1)$B$G$N%"%/%;%9$,2DG=$G$"$9$,!"(B
+   $B%G!<%?$N:o=|$K$O(BO(N)$B$H!"8zN($,NI$/$"$j$^$;$s!#FC$K%-%e!<9=B$$N$h$&$K(B
+   $B%G!<%?$N@hF,$+$i:o=|$7$F$$$/=hM}$,:G$bCY$$$N$G!"@'Hs$H$b$5$1$k$Y$-$G$9!#(B
+   </p>
+
+   <p>$B%/%i%$%"%s%HB&$N%3!<%I$G$O(Bs_vector_xarray()$B$rMQ$$$k$3$H$b8!F$$7$F$_$F(B
+   $B$/$@$5$$!#(B</p>
+*/
+
+#ifndef _SCALE_VECTOR_H_
+#define _SCALE_VECTOR_H_
 
 #include "scale/commons.h"
 #include "scale/iterator.h"
@@ -48,4 +64,4 @@ sxarray_t *		s_vector_xarray(void);
 sxarray_t *		s_vector_attach_xarray(svector_t *);
 
 
-#endif /* _SC_VECTOR_H_ */
+#endif /* _SCALE_VECTOR_H_ */
