@@ -1,7 +1,10 @@
 /**
- * $Id: sc_buffer.c,v 1.3 2004/06/21 16:44:17 jklein Exp $
+ * $Id: sc_buffer.c,v 1.4 2004/06/27 13:35:17 jklein Exp $
  * $Author: jklein $
  * $Log: sc_buffer.c,v $
+ * Revision 1.4  2004/06/27 13:35:17  jklein
+ * Added few functions for sbuffer_t and few macros for sxarray_t.
+ *
  * Revision 1.3  2004/06/21 16:44:17  jklein
  * Added iterator.
  *
@@ -50,6 +53,17 @@ s_buffer_alloc(size_t initsize)
 }
 
 
+sbuffer_t *
+s_buffer_alloc_str(const char *str)
+{
+	sbuffer_t *sbuf;
+
+	sbuf = s_buffer_alloc(strlen(str) + 1);
+	strcpy(sbuf->string, str);
+	return sbuf;
+}
+
+
 void
 s_buffer_free(sbuffer_t *sbuf)
 {
@@ -156,6 +170,39 @@ s_buffer_vsprintf(sbuffer_t *sbuf, const char *fmt, va_list ap)
 }
 
 
+void
+s_buffer_chrrep(sbuffer_t *sbuf, char src, char dst)
+{
+	char *p;
+
+	for (p=sbuf->string; *p != '\0'; ++p) {
+		if (*p == src)
+			*p = dst;
+	}
+}
+
+
+void
+s_buffer_strrep(sbuffer_t *sbuf, const char *src, const char *dst)
+{
+	sbuffer_t *tmpbuf = s_buffer_alloc(s_buffer_strlen(sbuf) + 16);
+	char *p, *repp;
+	size_t dstlen = strlen(dst);
+	size_t srclen = strlen(src);
+	
+	p = sbuf->string;
+	while ((repp = strstr(p, src)) != NULL) {
+		s_buffer_strncat(tmpbuf, p, repp - p);
+		s_buffer_strncat(tmpbuf, dst, dstlen);
+		p = repp + srclen;
+	}
+	s_buffer_strcat(tmpbuf, p);
+	
+	s_buffer_strcpy(sbuf, tmpbuf->string);
+	s_buffer_free(tmpbuf);
+}
+
+
 sint
 s_buffer_strcmp(const sbuffer_t *lbuf, const sbuffer_t *rbuf)
 {
@@ -168,3 +215,10 @@ s_buffer_strncmp(const sbuffer_t *lbuf, const sbuffer_t *rbuf, size_t n)
 {
 	return strncmp(lbuf->string, rbuf->string, n);
 }
+
+
+char *
+s_buffer_cstr(const sbuffer_t *sbuf)
+{
+	return sbuf->string;
+}
